# coding: utf-8

"""
    Vantage Management API

    This is a the API to interact with Vantage Discovery, the amazing Semantic Search Platform in the world.  We enable developers to build magical discovery experiences into their products and websites.  Some useful links: - [TODO: Semantic Search Guide: What Is It And Why Does It Matter?](https://www.bloomreach.com/en/blog/2019/semantic-search-explained-in-5-minutes)

    The version of the OpenAPI document: v1.1.2
    Contact: devrel@vantagediscovery.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings
from typing import Any, Dict, List, Optional, Tuple, Union

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call


try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from typing import List, Optional

from pydantic import Field, StrictInt, StrictStr
from typing_extensions import Annotated

from vantage_sdk.core.http.api_client import ApiClient
from vantage_sdk.core.http.api_response import ApiResponse
from vantage_sdk.core.http.models.collection import Collection
from vantage_sdk.core.http.models.collection_modifiable import (
    CollectionModifiable,
)
from vantage_sdk.core.http.models.collection_upload_url import (
    CollectionUploadURL,
)
from vantage_sdk.core.http.models.create_collection_request import (
    CreateCollectionRequest,
)
from vantage_sdk.core.http.rest import RESTResponseType


class CollectionManagementApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def create_collection(
        self,
        account_id: Annotated[
            StrictStr,
            Field(description="The account id to create this collection in"),
        ],
        create_collection_request: Annotated[
            CreateCollectionRequest,
            Field(
                description="Configuration required to create Collection.  This is central to Vantage"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Collection:
        """Create Collection

        Create a new <<glossary:collection>> in Vantage Discovery.  More information in [Collection Guide](/docs/collections)

        :param account_id: The account id to create this collection in (required)
        :type account_id: str
        :param create_collection_request: Configuration required to create Collection.  This is central to Vantage (required)
        :type create_collection_request: CreateCollectionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_collection_serialize(
            account_id=account_id,
            create_collection_request=create_collection_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def create_collection_with_http_info(
        self,
        account_id: Annotated[
            StrictStr,
            Field(description="The account id to create this collection in"),
        ],
        create_collection_request: Annotated[
            CreateCollectionRequest,
            Field(
                description="Configuration required to create Collection.  This is central to Vantage"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Collection]:
        """Create Collection

        Create a new <<glossary:collection>> in Vantage Discovery.  More information in [Collection Guide](/docs/collections)

        :param account_id: The account id to create this collection in (required)
        :type account_id: str
        :param create_collection_request: Configuration required to create Collection.  This is central to Vantage (required)
        :type create_collection_request: CreateCollectionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_collection_serialize(
            account_id=account_id,
            create_collection_request=create_collection_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def create_collection_without_preload_content(
        self,
        account_id: Annotated[
            StrictStr,
            Field(description="The account id to create this collection in"),
        ],
        create_collection_request: Annotated[
            CreateCollectionRequest,
            Field(
                description="Configuration required to create Collection.  This is central to Vantage"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Collection

        Create a new <<glossary:collection>> in Vantage Discovery.  More information in [Collection Guide](/docs/collections)

        :param account_id: The account id to create this collection in (required)
        :type account_id: str
        :param create_collection_request: Configuration required to create Collection.  This is central to Vantage (required)
        :type create_collection_request: CreateCollectionRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_collection_serialize(
            account_id=account_id,
            create_collection_request=create_collection_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _create_collection_serialize(
        self,
        account_id,
        create_collection_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_collection_request is not None:
            _body_params = create_collection_request

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ['application/json']
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/account/{account_id}/collection',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def delete_collection(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to deactivate {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Collection

        Mark as deactivated {collection_id}

        :param collection_id: The collection id to deactivate {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def delete_collection_with_http_info(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to deactivate {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Collection

        Mark as deactivated {collection_id}

        :param collection_id: The collection id to deactivate {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def delete_collection_without_preload_content(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to deactivate {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Collection

        Mark as deactivated {collection_id}

        :param collection_id: The collection id to deactivate {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _delete_collection_serialize(
        self,
        collection_id,
        account_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if collection_id is not None:
            _path_params['collection_id'] = collection_id
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/account/{account_id}/collection/{collection_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_browser_upload_url(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get an upload link for for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        file_size: Annotated[
            StrictInt,
            Field(
                description="The size of the file, in bytes, to be uploaded at url generated."
            ),
        ],
        customer_batch_identifier: Annotated[
            Optional[StrictStr],
            Field(
                description="The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CollectionUploadURL:
        """Collection Upload File

        Get an upload URL to be able to upload for ingestion into  {collection_id}

        :param collection_id: The collection id to get an upload link for for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param file_size: The size of the file, in bytes, to be uploaded at url generated. (required)
        :type file_size: int
        :param customer_batch_identifier: The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl.
        :type customer_batch_identifier: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_browser_upload_url_serialize(
            collection_id=collection_id,
            account_id=account_id,
            file_size=file_size,
            customer_batch_identifier=customer_batch_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionUploadURL",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def get_browser_upload_url_with_http_info(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get an upload link for for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        file_size: Annotated[
            StrictInt,
            Field(
                description="The size of the file, in bytes, to be uploaded at url generated."
            ),
        ],
        customer_batch_identifier: Annotated[
            Optional[StrictStr],
            Field(
                description="The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CollectionUploadURL]:
        """Collection Upload File

        Get an upload URL to be able to upload for ingestion into  {collection_id}

        :param collection_id: The collection id to get an upload link for for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param file_size: The size of the file, in bytes, to be uploaded at url generated. (required)
        :type file_size: int
        :param customer_batch_identifier: The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl.
        :type customer_batch_identifier: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_browser_upload_url_serialize(
            collection_id=collection_id,
            account_id=account_id,
            file_size=file_size,
            customer_batch_identifier=customer_batch_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionUploadURL",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def get_browser_upload_url_without_preload_content(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get an upload link for for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        file_size: Annotated[
            StrictInt,
            Field(
                description="The size of the file, in bytes, to be uploaded at url generated."
            ),
        ],
        customer_batch_identifier: Annotated[
            Optional[StrictStr],
            Field(
                description="The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Collection Upload File

        Get an upload URL to be able to upload for ingestion into  {collection_id}

        :param collection_id: The collection id to get an upload link for for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param file_size: The size of the file, in bytes, to be uploaded at url generated. (required)
        :type file_size: int
        :param customer_batch_identifier: The filename or batch identifier used to build the URL.  Typically will be the filename used in the browser upload.  If omitted, a guid is generated.  The GUID assumes a parquet format, all JSONL must be sent with customer_batch_identifier ending in .jsonl.
        :type customer_batch_identifier: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_browser_upload_url_serialize(
            collection_id=collection_id,
            account_id=account_id,
            file_size=file_size,
            customer_batch_identifier=customer_batch_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CollectionUploadURL",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_browser_upload_url_serialize(
        self,
        collection_id,
        account_id,
        file_size,
        customer_batch_identifier,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if collection_id is not None:
            _path_params['collection_id'] = collection_id
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        if file_size is not None:
            _query_params.append(('file_size', file_size))

        if customer_batch_identifier is not None:
            _query_params.append(
                ('customer_batch_identifier', customer_batch_identifier)
            )

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/account/{account_id}/collection/{collection_id}/get_upload_url',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_collection(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get details for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Collection:
        """Get Collection

        Get the collection object {collection_id}

        :param collection_id: The collection id to get details for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def get_collection_with_http_info(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get details for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Collection]:
        """Get Collection

        Get the collection object {collection_id}

        :param collection_id: The collection id to get details for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def get_collection_without_preload_content(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(
                description="The collection id to get details for {collection_id}"
            ),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Collection

        Get the collection object {collection_id}

        :param collection_id: The collection id to get details for {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_collection_serialize(
        self,
        collection_id,
        account_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if collection_id is not None:
            _path_params['collection_id'] = collection_id
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/account/{account_id}/collection/{collection_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_collections(
        self,
        account_id: Annotated[StrictStr, Field(description="The account id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Collection]:
        """List Collections

        List the collections in account_id

        :param account_id: The account id (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_collections_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Collection]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def list_collections_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="The account id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Collection]]:
        """List Collections

        List the collections in account_id

        :param account_id: The account id (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_collections_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Collection]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def list_collections_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="The account id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Collections

        List the collections in account_id

        :param account_id: The account id (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_collections_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Collection]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _list_collections_serialize(
        self,
        account_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/account/{account_id}/collection',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def update_collection(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(description="The collection id to update {collection_id}"),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        collection_modifiable: Annotated[
            CollectionModifiable,
            Field(description="Configuration required to update Collection."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Collection:
        """Update collection

        Update the collection object {collection_id}

        :param collection_id: The collection id to update {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param collection_modifiable: Configuration required to update Collection. (required)
        :type collection_modifiable: CollectionModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            collection_modifiable=collection_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def update_collection_with_http_info(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(description="The collection id to update {collection_id}"),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        collection_modifiable: Annotated[
            CollectionModifiable,
            Field(description="Configuration required to update Collection."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Collection]:
        """Update collection

        Update the collection object {collection_id}

        :param collection_id: The collection id to update {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param collection_modifiable: Configuration required to update Collection. (required)
        :type collection_modifiable: CollectionModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            collection_modifiable=collection_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def update_collection_without_preload_content(
        self,
        collection_id: Annotated[
            StrictStr,
            Field(description="The collection id to update {collection_id}"),
        ],
        account_id: Annotated[
            StrictStr,
            Field(
                description="The account id this collection id is located in"
            ),
        ],
        collection_modifiable: Annotated[
            CollectionModifiable,
            Field(description="Configuration required to update Collection."),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update collection

        Update the collection object {collection_id}

        :param collection_id: The collection id to update {collection_id} (required)
        :type collection_id: str
        :param account_id: The account id this collection id is located in (required)
        :type account_id: str
        :param collection_modifiable: Configuration required to update Collection. (required)
        :type collection_modifiable: CollectionModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_collection_serialize(
            collection_id=collection_id,
            account_id=account_id,
            collection_modifiable=collection_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Collection",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _update_collection_serialize(
        self,
        collection_id,
        account_id,
        collection_modifiable,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if collection_id is not None:
            _path_params['collection_id'] = collection_id
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if collection_modifiable is not None:
            _body_params = collection_modifiable

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ['application/json']
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/account/{account_id}/collection/{collection_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



from __future__ import annotations

import datetime
from typing import Optional

import requests

from vantage_sdk.config import (
    AUTH_ENDPOINT,
    DEFAULT_API_HOST,
    DEFAULT_AUTH_HOST,
    DEFAULT_ENCODING,
)
from vantage_sdk.core.http import ApiClient
from vantage_sdk.core.http.exceptions import UnauthorizedException


class AuthorizationClient:
    _DAY_IN_SECONDS = 86400

    def __init__(
        self,
        vantage_audience_url: str = DEFAULT_API_HOST,
        sso_endpoint_url: str = f"{DEFAULT_AUTH_HOST}{AUTH_ENDPOINT}",
        vantage_api_key: Optional[str] = None,
        vantage_client_id: Optional[str] = None,
        vantage_client_secret: Optional[str] = None,
        vantage_jwt_token: Optional[str] = None,
        encoding: str = DEFAULT_ENCODING,
    ) -> None:
        self._check_credentials(
            vantage_api_key=vantage_api_key,
            vantage_client_id=vantage_client_id,
            vantage_client_secret=vantage_client_secret,
            vantage_jwt_token=vantage_jwt_token,
        )

        self._vantage_api_key = vantage_api_key
        self._vantage_client_id = vantage_client_id
        self._vantage_client_secret = vantage_client_secret
        self._vantage_audience_url = vantage_audience_url
        self._sso_endpoint_url = sso_endpoint_url
        self._encoding = encoding

        if vantage_jwt_token:
            now = datetime.datetime.now().timestamp() * 1000
            self._jwt_token = {
                "token": vantage_jwt_token,
                "valid_until": now + AuthorizationClient._DAY_IN_SECONDS,
            }
        else:
            self._jwt_token = None

    def _check_credentials(
        self,
        vantage_api_key: Optional[str] = None,
        vantage_client_id: Optional[str] = None,
        vantage_client_secret: Optional[str] = None,
        vantage_jwt_token: Optional[str] = None,
    ):
        if (
            not vantage_api_key
            and not vantage_jwt_token
            and not (vantage_client_id and vantage_client_secret)
        ):
            raise ValueError(
                (
                    "Please provide Vantage API key or Vantage JWT token, or both Client ID and secret. ",
                    "None of these was found.",
                )
            )

    def _authenticate(self) -> dict:
        headers = {'Content-Type': 'application/x-www-form-urlencoded'}
        body = {
            "client_id": self._vantage_client_id,
            "client_secret": self._vantage_client_secret,
            "grant_type": "client_credentials",
            "audience": self._vantage_audience_url,
        }

        return requests.post(
            self._sso_endpoint_url, data=body, headers=headers
        ).json()

    def _has_expired(self) -> bool:
        if self._jwt_token is None:
            self._get_new_token()

        if self._jwt_token is None:
            raise ValueError("Authentication failed.")

        valid_until = self._jwt_token["valid_until"]
        now = datetime.datetime.now().timestamp() * 1000

        # Subtracting 5s not to wait for the last moment to obtain new token.
        return (valid_until - 5000) - now >= 0

    def _get_new_token(self):
        if self._vantage_api_key or self._jwt_token:
            return

        authentication = self._authenticate()
        now = datetime.datetime.now().timestamp() * 1000
        self._jwt_token = {
            "token": authentication['access_token'],
            "valid_until": now + authentication["expires_in"],
        }

    @property
    def jwt_token(self) -> str:
        if self._jwt_token:
            return self._jwt_token["token"]

        if self._jwt_token is None or self._has_expired():
            self._get_new_token()

        if self._jwt_token is None:
            raise ValueError("Authentication failed.")

        return self._jwt_token["token"]

    def authenticate(self):
        if self._vantage_api_key or self._jwt_token:
            return

        self._get_new_token()
        if self._jwt_token is None:
            raise ValueError("Authentication failed.")

    @classmethod
    def automatic_token_management(
        cls,
        vantage_api_key: str,
        vantage_client_id: str,
        vantage_client_secret: str,
        vantage_audience_url: str,
        sso_endpoint_url: str,
    ) -> AuthorizationClient:
        return cls(
            vantage_api_key=vantage_api_key,
            vantage_client_id=vantage_client_id,
            vantage_client_secret=vantage_client_secret,
            vantage_jwt_token=None,
            vantage_audience_url=vantage_audience_url,
            sso_endpoint_url=sso_endpoint_url,
        )

    @classmethod
    def using_provided_vantage_api_key(cls, vantage_api_key: str):
        return cls(vantage_api_key=vantage_api_key)

    @classmethod
    def using_provided_token(cls, vantage_jwt_token: str):
        return cls(vantage_jwt_token=vantage_jwt_token)


class AuthorizedApiClient(ApiClient):
    def __init__(
        self,
        authorization_client: AuthorizationClient,
        configuration=None,
        header_name=None,
        header_value=None,
        cookie=None,
    ) -> None:
        super().__init__(
            configuration=configuration,
            header_name=header_name,
            header_value=header_value,
            cookie=cookie,
        )
        self.authorization_client = authorization_client

    def call_api(
        self,
        method,
        url,
        header_params=None,
        body=None,
        post_params=None,
        _request_timeout=None,
    ):
        args = (
            method,
            url,
            header_params,
            body,
            post_params,
            _request_timeout,
        )
        if "authorization" in header_params:
            return super().call_api(*args)

        try:
            auth_string = (
                self.authorization_client._vantage_api_key
                if self.authorization_client._vantage_api_key
                else self.authorization_client.jwt_token
            )
            header_params["authorization"] = f"Bearer {auth_string}"
            return super().call_api(*args)
        except UnauthorizedException:
            self.authorization_client.authenticate()
            header_params[
                "authorization"
            ] = f"Bearer {self.authorization_client.jwt_token}"
            return super().call_api(*args)



"""This module contains SearchAPI, a class for accessing search API."""

from vantage_sdk.core.http.api.search_api import SearchApi
from vantage_sdk.core.http.api_client import ApiClient


class SearchAPI:
    """
    Component for accessing the search API.

    Attributes
    ----------
    api: SearchApi
        Component used to access the search API.
    """

    def __init__(self, api_client: ApiClient):
        """
        Default constructor.

        Parameters
        ----------
        api_client: ApiClient
            Component used to make HTTP calls to the API.
        """
        self.api = SearchApi(api_client=api_client)



from typing import Optional

from pydantic import ValidationError


class VantageException(Exception):
    """The base exception class for all Vantage client exceptions."""


class VantageNotFoundError(VantageException):
    """Thrown if requested resource is not found."""

    def __init__(self, message: str):
        self.message = message


class VantageValueError(VantageException, ValueError):
    """Thrown if value(s) passed to the API are incorrect in given context."""

    def __init__(self, error_msg: str):
        super(VantageValueError, self).__init__(error_msg)


class VantageFileUploadError(VantageException):
    """Thrown if error occurs while uploading a file."""

    def __init__(self, error_msg: str, status_code: int):
        super(VantageFileUploadError, self).__init__(error_msg, status_code)


class VantageServiceError(VantageException):
    """
    Thrown if the API server reports a HTTP 500 error during normal usage.
    """

    def __init__(self, reason: str, status: int, response: str):
        self.reason = reason
        self.status = status
        self.response = response


class VantageInvalidRequestError(VantageException):
    """Thrown if user sends invalid request to the API."""

    def __init__(self, reason: str, status: int, response: str):
        self.reason = reason
        self.status = status
        self.response = response


class VantageInvalidResponseError(VantageException):
    """Thrown if server returns invalid response."""

    def __init__(
        self,
        error_message: str,
        validation_error: Optional[ValidationError] = None,
    ):
        self.error_message = error_message
        self.validation_error = validation_error


class VantageUnauthorizedError(VantageException):
    """Thrown if user tries to access the API without valid authorization."""

    def __init__(self, error_msg: str):
        super(VantageUnauthorizedError, self).__init__(error_msg)


class VantageForbiddenError(VantageException):
    """Thrown if unauthenticated user tries to access the API."""

    def __init__(self, error_msg: str):
        super(VantageForbiddenError, self).__init__(error_msg)



# coding: utf-8

"""
    Vantage Management API

    This is a the API to interact with Vantage Discovery, the amazing Semantic Search Platform in the world.  We enable developers to build magical discovery experiences into their products and websites.  Some useful links: - [TODO: Semantic Search Guide: What Is It And Why Does It Matter?](https://www.bloomreach.com/en/blog/2019/semantic-search-explained-in-5-minutes)

    The version of the OpenAPI document: v1.1.2
    Contact: devrel@vantagediscovery.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings
from typing import Any, Dict, List, Optional, Tuple, Union

from pydantic import Field, StrictFloat, StrictInt, StrictStr, validate_call


try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from typing import List

from pydantic import Field, StrictStr
from typing_extensions import Annotated

from vantage_sdk.core.http.api_client import ApiClient
from vantage_sdk.core.http.api_response import ApiResponse
from vantage_sdk.core.http.models.vantage_vibe import VantageVibe
from vantage_sdk.core.http.models.vantage_vibe_modifiable import (
    VantageVibeModifiable,
)
from vantage_sdk.core.http.rest import RESTResponseType


class VantageVibeApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def create_vantage_vibe(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Vantage Vibe configuration details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VantageVibe:
        """Create Vantage Vibe configuration

        Create Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vantage_vibe_modifiable: Vantage Vibe configuration details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_vantage_vibe_serialize(
            account_id=account_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def create_vantage_vibe_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Vantage Vibe configuration details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VantageVibe]:
        """Create Vantage Vibe configuration

        Create Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vantage_vibe_modifiable: Vantage Vibe configuration details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_vantage_vibe_serialize(
            account_id=account_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def create_vantage_vibe_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Vantage Vibe configuration details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Vantage Vibe configuration

        Create Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vantage_vibe_modifiable: Vantage Vibe configuration details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_vantage_vibe_serialize(
            account_id=account_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _create_vantage_vibe_serialize(
        self,
        account_id,
        vantage_vibe_modifiable,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if vantage_vibe_modifiable is not None:
            _body_params = vantage_vibe_modifiable

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ['application/json']
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/account/{account_id}/vibe',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def delete_vantage_vibe(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Vantage Vibe configuration

        Delete Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def delete_vantage_vibe_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Vantage Vibe configuration

        Delete Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def delete_vantage_vibe_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Vantage Vibe configuration

        Delete Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _delete_vantage_vibe_serialize(
        self,
        account_id,
        vibe_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        if vibe_id is not None:
            _path_params['vibe_id'] = vibe_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/account/{account_id}/vibe/{vibe_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_vantage_vibe(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VantageVibe:
        """Get Vantage Vibe configuration

        Get Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def get_vantage_vibe_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VantageVibe]:
        """Get Vantage Vibe configuration

        Get Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def get_vantage_vibe_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Vantage Vibe configuration

        Get Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_vantage_vibe_serialize(
        self,
        account_id,
        vibe_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        if vibe_id is not None:
            _path_params['vibe_id'] = vibe_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/account/{account_id}/vibe/{vibe_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_vantage_vibe(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[VantageVibe]:
        """List Vantage Vibe configurations

        List Vantage Vibe configurations

        :param account_id: User account ID (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_vantage_vibe_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VantageVibe]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def list_vantage_vibe_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[VantageVibe]]:
        """List Vantage Vibe configurations

        List Vantage Vibe configurations

        :param account_id: User account ID (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_vantage_vibe_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VantageVibe]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def list_vantage_vibe_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Vantage Vibe configurations

        List Vantage Vibe configurations

        :param account_id: User account ID (required)
        :type account_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_vantage_vibe_serialize(
            account_id=account_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[VantageVibe]",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _list_vantage_vibe_serialize(
        self,
        account_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/account/{account_id}/vibe',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def update_vantage_vibe(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Shopping assistant details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VantageVibe:
        """Update Vantage Vibe configuration

        Update Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param vantage_vibe_modifiable: Shopping assistant details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def update_vantage_vibe_with_http_info(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Shopping assistant details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VantageVibe]:
        """Update Vantage Vibe configuration

        Update Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param vantage_vibe_modifiable: Shopping assistant details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def update_vantage_vibe_without_preload_content(
        self,
        account_id: Annotated[StrictStr, Field(description="User account ID")],
        vibe_id: Annotated[
            StrictStr, Field(description="Vantage Vibe configuration ID")
        ],
        vantage_vibe_modifiable: Annotated[
            VantageVibeModifiable,
            Field(description="Shopping assistant details"),
        ],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)],
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Vantage Vibe configuration

        Update Vantage Vibe configuration

        :param account_id: User account ID (required)
        :type account_id: str
        :param vibe_id: Vantage Vibe configuration ID (required)
        :type vibe_id: str
        :param vantage_vibe_modifiable: Shopping assistant details (required)
        :type vantage_vibe_modifiable: VantageVibeModifiable
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_vantage_vibe_serialize(
            account_id=account_id,
            vibe_id=vibe_id,
            vantage_vibe_modifiable=vantage_vibe_modifiable,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VantageVibe",
            '405': None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _update_vantage_vibe_serialize(
        self,
        account_id,
        vibe_id,
        vantage_vibe_modifiable,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if account_id is not None:
            _path_params['account_id'] = account_id
        if vibe_id is not None:
            _path_params['vibe_id'] = vibe_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if vantage_vibe_modifiable is not None:
            _body_params = vantage_vibe_modifiable

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json']
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(
                ['application/json']
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ['BearerAuth']

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/account/{account_id}/vibe/{vibe_id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""
Models for the Account API.
"""

from typing import Optional

from pydantic import BaseModel, StrictStr


class Account(BaseModel):
    """
    Represents user's account.

    Parameters
    ----------
    account_id : Optional[str]
        ID of the user's account.
    account_name : Optional[str]
        Name of the user's account.
    """

    account_id: Optional[StrictStr] = None
    account_name: Optional[StrictStr] = None



#!/usr/bin/env bash

from typing import List

import pytest

from tests.integration_tests.utilities import create_temporary_upe_collection
from vantage_sdk.client import VantageClient
from vantage_sdk.model.collection import UserProvidedEmbeddingsCollection
from vantage_sdk.model.document import (
    UserProvidedEmbeddingsDocument,
    VantageManagedEmbeddingsDocument,
)


"""Integration tests for document upsert endpoints"""


class TestDocuments:
    def test_user_provided_documents_upsert(
        self,
        client: VantageClient,
        api_params: dict,
        account_params: dict,
        test_collection_id: str,
        vantage_upe_documents: List[UserProvidedEmbeddingsDocument],
    ):
        """
        TODO: docstring
        """
        # Given
        collection_id = test_collection_id
        collection_name = test_collection_id

        collection = UserProvidedEmbeddingsCollection(
            collection_id=collection_id,
            collection_name=collection_name,
            embeddings_dimension=3,
        )
        create_temporary_upe_collection(
            client=client,
            collection=collection,
            account_id=account_params["id"],
        )

        # When
        client.upsert_documents(
            collection_id=collection_id,
            documents=vantage_upe_documents,
            account_id=account_params["id"],
        )

        # Then
        # Do nothing, if exception has not been thrown, everything is fine

    def test_user_provided_documents_upsert_invalid_document_type(
        self,
        client: VantageClient,
        api_params: dict,
        account_params: dict,
        test_collection_id: str,
        vantage_vme_documents: List[VantageManagedEmbeddingsDocument],
    ):
        # Given
        collection_id = test_collection_id
        collection_name = test_collection_id

        collection = UserProvidedEmbeddingsCollection(
            collection_id=collection_id,
            collection_name=collection_name,
            embeddings_dimension=3,
        )
        create_temporary_upe_collection(
            client=client,
            collection=collection,
            account_id=account_params["id"],
        )

        # When
        with pytest.raises(ValueError) as exception:
            client.upsert_documents(
                collection_id=collection_id,
                documents=vantage_vme_documents,
                account_id=account_params["id"],
            )

        # Then
        assert exception.type is ValueError

    def test_documents_upsert_from_jsonl_file(
        self,
        client: VantageClient,
        api_params: dict,
        account_params: dict,
        test_collection_id: str,
        jsonl_documents_path: str,
    ):
        """
        TODO: docstring
        """
        # Given
        collection_id = test_collection_id
        collection_name = test_collection_id

        collection = UserProvidedEmbeddingsCollection(
            collection_id=collection_id,
            collection_name=collection_name,
            embeddings_dimension=3,
        )
        create_temporary_upe_collection(
            client=client,
            collection=collection,
            account_id=account_params["id"],
        )

        # When
        client.upsert_documents_from_jsonl_file(
            collection_id=collection_id,
            jsonl_file_path=jsonl_documents_path,
            account_id=account_params["id"],
        )

        # Then
        # Do nothing, if exception has not been thrown, everything is fine

    def test_documents_upload_from_parquet_file(
        self,
        client: VantageClient,
        account_params: dict,
        api_params: dict,
        test_collection_id: str,
        parquet_file_path: str,
    ):
        """
        TODO: docstring
        """
        # Given
        collection_id = test_collection_id
        collection_name = test_collection_id

        collection = UserProvidedEmbeddingsCollection(
            collection_id=collection_id,
            collection_name=collection_name,
            embeddings_dimension=3,
        )
        create_temporary_upe_collection(
            client=client,
            collection=collection,
            account_id=account_params["id"],
        )

        # When
        result = client.upload_documents_from_parquet_file(
            collection_id=collection_id,
            parquet_file_path=parquet_file_path,
            account_id=account_params["id"],
        )

        assert result == 200

    def test_documents_upload_from_jsonl_file(
        self,
        client: VantageClient,
        account_params: dict,
        api_params: dict,
        test_collection_id: str,
        jsonl_documents_path: str,
    ):
        """
        TODO: docstring
        """
        # Given
        collection_id = test_collection_id
        collection_name = test_collection_id

        collection = UserProvidedEmbeddingsCollection(
            collection_id=collection_id,
            collection_name=collection_name,
            embeddings_dimension=3,
        )
        create_temporary_upe_collection(
            client=client,
            collection=collection,
            account_id=account_params["id"],
        )

        # When
        result = client.upload_documents_from_jsonl_file(
            collection_id=collection_id,
            jsonl_file_path=jsonl_documents_path,
            account_id=account_params["id"],
        )

        assert result == 200



"""
Models for the Search API.
"""

from enum import Enum
from typing import Any, Dict, List, Optional, Union

from pydantic import (
    BaseModel,
    StrictFloat,
    StrictInt,
    StrictStr,
    model_validator,
)

from vantage_sdk.core.http.models import (
    SearchOptionsCollection,
    SearchOptionsFacetsInner,
    SearchOptionsFieldValueWeighting,
    SearchOptionsFilter,
    SearchOptionsPagination,
    SearchOptionsSort,
    WeightedFieldValues,
)


class SearchResultItem(BaseModel):
    """
    Represents an individual search result item.

    Attributes
    ----------
    id : Optional[StrictStr], optional
        The unique identifier of the document in the collection.
    score : Optional[Union[StrictFloat, StrictInt]], optional
        The similarity score associated with the document.
    sort_score : Optional[Union[StrictFloat, StrictInt]], optional
        The sort score associated with the document.
    variants : Optional[Union[StrictFloat, StrictInt]], optional
        The top variants of the document.
    variants_full_list : Optional[Union[StrictFloat, StrictInt]], optional
        All variants of the document.
    """

    id: Optional[StrictStr] = None
    score: Optional[Union[StrictFloat, StrictInt]] = None
    sort_score: Optional[Union[StrictFloat, StrictInt]] = None
    variants: Optional[List[StrictStr]] = None
    variants_full_list: Optional[List[StrictStr]] = None


class FacetResultItem(BaseModel):
    facet: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    values: Optional[Dict[str, Any]] = None


class SearchResult(BaseModel):
    """
    Represents the result received from all search methods.

    Attributes
    ----------
    request_id : Optional[StrictInt], optional
        The unique identifier for the search request.
    status : Optional[StrictInt], optional
        The status code of the search response.
    message : Optional[StrictStr], optional
        A message providing additional information about the search response.
    results : Optional[List[SearchResultItem]], optional
        A list of search result items returned by the search method.
    facets: Optional[List[FacetResultItem]], optional
        A list of facet result items returned by the search method.
    """

    request_id: Optional[StrictInt] = None
    status: Optional[StrictInt] = None
    message: Optional[StrictStr] = None
    results: Optional[List[SearchResultItem]] = None
    facets: Optional[List[FacetResultItem]] = None


class ApproximateResultsCountResult(BaseModel):
    """
    Represents the result received from Approximate Result Search.

    Attributes
    ----------
    total_count: Optional[StrictInt], optional
        Total count of documents within the specified threshold.
    """

    total_count: Optional[StrictInt] = None


class MoreLikeTheseItem(BaseModel):
    """
    Represents an item for "More Like These" queries.

    One of `query_text`, `query_document_id`, or `embedding` should be provided.

    Attributes
    ----------
    weight : StrictFloat
        The weight/importance assigned to this item in the query.
    query_text : StrictStr
        The text used for the query.
    query_document_id : Optional[StrictStr], optional
        The document ID used for the query.
    embedding : Optional[list[Union[StrictInt, StrictFloat]]], optional
        The embedding vector associated with the query.
    """

    weight: StrictFloat
    query_text: StrictStr
    query_document_id: Optional[StrictStr] = None
    embedding: Optional[list[StrictInt | StrictFloat]] = None
    these: Optional[list[dict[StrictStr, Any]]] = None

    @model_validator(mode="before")
    def check_mutually_exclusive_fields(cls, values):
        query_text = values.get('query_text')
        query_document_id = values.get('query_document_id')
        embedding = values.get('embedding')

        if (
            sum([bool(query_text), bool(query_document_id), bool(embedding)])
            > 1
        ):
            raise ValueError(
                'Only one of `query_text`, `query_document_id`, or `embedding` should be provided.'
            )

        if not any([query_text, query_document_id, embedding]):
            raise ValueError(
                'One of `query_text`, `query_document_id`, or `embedding` must be provided.'
            )

        return values


class Filter(BaseModel):
    boolean_filter: Optional[str] = None
    variant_filter: Optional[str] = None


class Pagination(BaseModel):
    page: Optional[int] = None
    count: Optional[int] = None
    threshold: Optional[int] = None


class Sort(BaseModel):
    field: Optional[str] = None
    order: Optional[str] = None
    mode: Optional[str] = None


class WeightedFieldValueItem(BaseModel):
    field: Optional[str] = None
    value: Optional[str] = None
    weight: Optional[float] = None


class FieldValueWeighting(BaseModel):
    query_key_word_max_overall_weight: Optional[float] = None
    query_key_word_weighting_mode: Optional[str] = None
    weighted_field_values: Optional[List[WeightedFieldValueItem]] = None

    # Pydantic Config
    class Config:
        arbitrary_types_allowed = True

    def pydantic_weighted_field_values(
        self,
    ) -> Optional[List[WeightedFieldValues]]:
        if not self.weighted_field_values:
            return None

        return [
            WeightedFieldValues(
                field=item.field,
                value=item.value,
                weight=item.weight,
            )
            for item in self.weighted_field_values
        ]


class FacetType(Enum):
    COUNT = "count"


class Facet(BaseModel):
    name: str
    type: FacetType
    values: Optional[List[str]] = []


class VantageVibeImageAllFields(BaseModel):
    url: Optional[str] = None
    base64: Optional[str] = None


class VantageVibeImageUrl(VantageVibeImageAllFields):
    def __init__(self, url):
        super().__init__(url=url)


class VantageVibeImageBase64(VantageVibeImageAllFields):
    def __init__(self, base64):
        super().__init__(base64=base64)


class SearchOptions(BaseModel):
    """
    Represents the global properties for all search methods.

    Attributes
    ----------
    collection : Optional[SearchOptionsCollection], optional
        The collection properties.
    filter : Optional[SearchOptionsFilter], optional
        The filter properties.
    pagination : Optional[SearchOptionsPagination], optional
        The pagination properties.
    sort : Optional[SearchOptionsSort], optional
        The sort properties.
    field_value_weighting : Optional[SearchOptionsFieldValueWeighting], optional
        The field value weighting properties.
    facets: Optional[List[SearchOptionsFacetsInner]], optional
        An array of objects that define the facets you want to use in your query.
    """

    collection: Optional[SearchOptionsCollection] = None
    filter: Optional[SearchOptionsFilter] = None
    pagination: Optional[SearchOptionsPagination] = None
    sort: Optional[SearchOptionsSort] = None
    field_value_weighting: Optional[SearchOptionsFieldValueWeighting] = None
    facets: Optional[List[SearchOptionsFacetsInner]] = None


class TotalCountsOptions(BaseModel):
    """
    Represents threshold value for documents similarity score.

    Attributes
    ----------
    min_score_threshold: Optional[Union[StrictFloat, StrictInt]]
        Minimum score value in range 0.0 to 1.0. Both limits are inclusive.
    max_score_threshold: Optional[Union[StrictFloat, StrictInt]]
        Maximum score value in range 0.0 to 1.0. Both limits are inclusive.
    """

    min_score_threshold: Optional[Union[StrictFloat, StrictInt]] = None
    max_score_threshold: Optional[Union[StrictFloat, StrictInt]] = None
